@@ -14,19 +14,17 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.2.9'
+__version__ = 'v1.3.0'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
             save_dir):
         self.js_file = js_file
+        self.json_output_dir = os.path.join(link_path, '_json_output')
+        self.save_dir = save_dir
         if save_dir:
-            print('>>>>>>>>>>>>>>>>>')
-            dirname = os.path.dirname(self.js_file).strip('./')
-            print(dirname)
-            self.link_path = os.path.join(link_path, '_json_output', dirname)
-            print(self.link_path)
-            print('>>>>>>>>>>>>>>>>>')
+            self.dirname = os.path.dirname(self.js_file).strip('./')
+            self.link_path = os.path.join(link_path, '_json_output', self.dirname)
         else:
             self.link_path = os.path.join(link_path, '_json_output')
         self.dir_type = dir_type
@@ -495,13 +493,13 @@ class TranslateJson(object):
     def check_file(self, file_name):
         if self.dir_type != "link":
             return
-        if os.path.exists(os.path.join(self.link_path, file_name)):
+        if os.path.exists(os.path.join(self.json_output_dir, file_name)):
             add_cmd = "cat " + os.path.join(self.gitbookpath, file_name) + " >> " \
-                    + os.path.join(self.link_path, file_name)
+                    + os.path.join(self.json_output_dir, file_name)
             os.system(add_cmd)
         else:
             mv_cmd = "mv " + os.path.join(self.gitbookpath, file_name) + " " \
-                    + os.path.join(self.link_path, file_name)
+                    + os.path.join(self.json_output_dir, file_name)
             os.system(mv_cmd)
 
     def relist(self, in_list):
@@ -575,7 +573,10 @@ class TranslateJson(object):
                 print("\n\tcreate " + self.gitbookpath +" success") 
             elif self.dir_type == "link":
                 self.gitbookpath = os.path.join(self.link_path, file_msg)
-                path_msg = "_json_output/" + str(file_msg)
+                if self.save_dir:
+                    path_msg = os.path.join("_json_output/", self.dirname, str(file_msg))
+                else:
+                    path_msg = "_json_output/" + str(file_msg)
                 if not os.path.exists(self.gitbookpath):
                     os.system("mkdir -p " + self.gitbookpath)
                 readme = os.path.join(self.gitbookpath, 'README.md')
@@ -656,8 +657,9 @@ def usage():
 
     parameters:
         -f : 指定json文件
+        -d : 加-d ,保留-f所指路径层级, 不加-d 只保留-f所指的文件名
         -g : 加-g ,生成gitbook目录, 不加-g 生成单个markdown文件
-        -l : 指定链接目录, 把生成的gitbook目录,放到指定目录下
+        -l : 指定链接目录, 把生成的gitbook目录,放到指定目录下(加-l 默认加上了-g)
     """
     print(usage.__doc__)
 
